summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorEric Lambert <eric_lambert@xyratex.com>2014-07-29 15:53:22 -0700
committerEric Lambert <eric_lambert@xyratex.com>2014-07-29 15:53:22 -0700
commitd6613f4e909749a878fe5c9b190f9935c8c0738c (patch)
tree85ad5c11dbe8b551369be93b676b80f7dbb5c65a /include
parent7fe555b06878ffbc3c612f151ac977a64529019d (diff)
parent6671c45b03489ab19f2d74864e4bb94c0e1333e1 (diff)
downloadliberasurecode-d6613f4e909749a878fe5c9b190f9935c8c0738c.tar.gz
Merge branch 'newapi' of https://bitbucket.org/tsg-/liberasurecode into newapi
Diffstat (limited to 'include')
-rw-r--r--include/erasurecode/erasurecode.h18
1 files changed, 14 insertions, 4 deletions
diff --git a/include/erasurecode/erasurecode.h b/include/erasurecode/erasurecode.h
index a56ebb5..4088ef8 100644
--- a/include/erasurecode/erasurecode.h
+++ b/include/erasurecode/erasurecode.h
@@ -94,11 +94,16 @@ struct ec_args {
/* liberasurecode frontend API functions */
/**
* Returns a list of EC backends implemented/enabled - the user should always
* rely on the return from this function as this set of backends can be
* different from the names listed in ec_backend_names above.
*/
-void liberasurecode_supported_backends(char **backend_names);
+const char ** liberasurecode_supported_backends(int *num_backends);
/**
* Create a liberasurecode instance and return a descriptor
@@ -161,6 +166,10 @@ int liberasurecode_encode(int desc,
* @param fragment_len - length of each fragment (assume they are the same)
* @param out_data - _output_ pointer to decoded data
* @param out_data_len - _output_ length of decoded output
+ * (both output data pointers are allocated by liberasurecode,
+ * caller invokes liberasurecode_decode_clean() after it has
+ * read decoded data in 'out_data')
+ *
* @return 0 on success, -error code otherwise
*/
int liberasurecode_decode(int desc,
@@ -178,6 +187,7 @@ int liberasurecode_decode(int desc,
* @param num_fragments - number of fragments being passed in
* @param destination_idx - missing idx to reconstruct
* @param out_fragment - output of reconstruct
+ *
* @return 0 on success, -error code otherwise
*/
int liberasurecode_reconstruct_fragment(int desc,
@@ -94,11 +94,16 @@ struct ec_args {
/* liberasurecode frontend API functions */
/**
- * Returns a list of EC backends implemented/enabled - the user should always
- * rely on the return from this function as this set of backends can be
- * different from the names listed in ec_backend_names above.
+ * Returns a list of EC backends implemented/enabled - the user
+ * should always rely on the return from this function as this
+ * set of backends can be different from the names listed in
+ * ec_backend_names above.
+ *
+ * @param num_backends - pointer to return number of backends in
+ *
+ * @returns
*/